@@ -77,10 +77,11 @@ class Mlx5Sriov(BaseSriov):
 
     def get_num_vf(self):
         # to get the count of vfs
-        cmd = f"cat /sys/class/infiniband/{self.hca_id}/device/sriov_numvfs"
-        retcode, output = run(cmd, return_output=True)
-        if retcode == 0:
-            return output
+        filepath_sriov_numvfs = f"/sys/class/infiniband/{self.hca_id}/device/sriov_numvfs"
+        if os.path.isfile(filepath_sriov_numvfs):
+            with open(filepath_sriov_numvfs) as sriov_numvfs:
+                numvfs = int(sriov_numvfs.read().strip())
+                return numvfs
         else:
             return None
 
